@@ -29,9 +29,6 @@ setAs("SpatialPolygonsDataFrame", "data.frame", function(from)
 setMethod("[", "SpatialPolygonsDataFrame", function(x, i, j, ... , drop = TRUE) {
     missing.i = missing(i)
     missing.j = missing(j)
-    drop <- FALSE
-#    if (drop)
-#       stop("coerce to data.frame first for drop = TRUE")
     nargs = nargs() # e.g., a[3,] gives 2 for nargs, a[3] gives 1.
     if (missing.i && missing.j) {
         i = TRUE
@@ -74,3 +71,6 @@ setMethod("summary", "SpatialPolygonsDataFrame", summary.Spatial)
 setMethod("coordinates", "SpatialPolygonsDataFrame", 
 	function(obj) getSpPPolygonsLabptSlots(obj))
 
+setAs("SpatialPolygonsDataFrame", "SpatialLinesDataFrame", 
+	function(from) SpatialLinesDataFrame(as(from, "SpatialLines"),
+		from@data, match.ID = FALSE))
